netapp_ontap.models.interface_statistics API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.interface_statistics`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class InterfaceStatisticsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the InterfaceStatistics object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `status GET`

    Errors associated with the sample. For example, if the aggregation of data over multiple nodes fails, then any partial errors might return "ok" on success or "error" on an internal uncategorized failure. Whenever a sample collection is missed but done at a later time, it is back filled to the previous 15 second timestamp and tagged with "backfilled_data". "inconsistent_delta_time" is encountered when the time between two collections is not the same for all nodes. Therefore, the aggregated value might be over or under inflated. "Negative_delta" is returned when an expected monotonically increasing value has decreased in value. "inconsistent_old_data" is returned when one or more nodes do not have the latest data.

    Valid choices:

    - ok
    - error
    - partial_no_data
    - partial_no_uuid
    - partial_no_response
    - partial_other_error
    - negative_delta
    - backfilled_data
    - inconsistent_delta_time
    - inconsistent_old_data
  `throughput_raw GET`

    The throughput_raw field of the interface_statistics.

  `timestamp GET`

    The timestamp of the performance data.

    Example: 2017-01-25T11:20:13.000+0000